'use strict';

const expect = require('chai').expect;
const stringUtils = require('@src/utils/string-utils');


describe('Utils test - string utility', () => {
    describe('# test function isNonEmptyString', () => {
        [
            {
                testCase: 'input is an object',
                str: {},
                expectation: false
            },
            {
                testCase: 'input is an array',
                str: [1, 2, 3],
                expectation: false
            },
            {
                testCase: 'input is a boolean',
                str: true,
                expectation: false
            },
            {
                testCase: 'input is an empty string',
                str: '',
                expectation: false
            },
            {
                testCase: 'input is a blank string',
                str: '      ',
                expectation: true
            },
            {
                testCase: 'input is a string with actual content',
                str: ' test string ',
                expectation: true
            },
        ].forEach(({ testCase, str, expectation }) => {
            it(`| ${testCase}, expect isNonEmptyString ${expectation}`, () => {
                // call
                const callResult = stringUtils.isNonEmptyString(str);
                // verify
                expect(callResult).equal(expectation);
            });
        });
    });

    describe('# test function isNonBlankString', () => {
        [
            {
                testCase: 'input is an object',
                str: {},
                expectation: false
            },
            {
                testCase: 'input is an array',
                str: [1, 2, 3],
                expectation: false
            },
            {
                testCase: 'input is a boolean',
                str: true,
                expectation: false
            },
            {
                testCase: 'input is an empty string',
                str: '',
                expectation: false
            },
            {
                testCase: 'input is a blank string',
                str: '      ',
                expectation: false
            },
            {
                testCase: 'input is a string with actual content',
                str: ' test string ',
                expectation: true
            },
        ].forEach(({ testCase, str, expectation }) => {
            it(`| ${testCase}, expect isNonBlankString ${expectation}`, () => {
                // call
                const callResult = stringUtils.isNonBlankString(str);
                // verify
                expect(callResult).equal(expectation);
            });
        });
    });

    describe('# test function isLambdaFunctionName', () => {
        [
            {
                testCase: 'input url string is null',
                str: null,
                expectation: false
            },
            {
                testCase: 'input url string is undefined',
                str: undefined,
                expectation: false
            },
            {
                testCase: 'input url string is empty',
                str: '',
                expectation: false
            },
            {
                testCase: 'input url string is blank',
                str: '        ',
                expectation: false
            },
            {
                testCase: 'input url string is valid function name',
                str: 'ask-custom-cityGuide-default',
                expectation: true
            },
            {
                testCase: 'input url string is http',
                str: 'http://lambda.arn.com',
                expectation: false
            },
            {
                testCase: 'input url string is https',
                str: 'https://test.com',
                expectation: false
            },
            {
                testCase: 'input url is random string',
                str: 'abc:A:<http://lambda>/invoke',
                expectation: false
            }

        ].forEach(({ testCase, str, expectation }) => {
            it(`| ${testCase}, expect isLambdaFunctionName ${expectation}`, () => {
                // call
                const callResult = stringUtils.isLambdaFunctionName(str);
                // verify
                expect(callResult).equal(expectation);
            });
        });
    });
});



